@@ -5,7 +5,7 @@ from toolz import curry
 def omit(keys, dict):
     """Returns a partial copy of an object omitting the keys specified"""
     picked_dict = {}
-    for k in keys:
-        if k not in dict:
+    for k in dict.keys():
+        if k not in keys:
             picked_dict[k] = dict[k]
     return picked_dict
