@@ -6,7 +6,4 @@ from ramda.path import path as _path
 def path_satisfies(predicate, path, value):
     """Returns true if the specified object property at given path satisfies the
     given predicate; false otherwise"""
-    try:
-        return predicate(_path(path, value))
-    except KeyError:
-        return False
+    return predicate(_path(path, value))
