@@ -14,6 +14,16 @@ def sub2(x):
     return x - 2
 
 
+piped = pipe(sub2, double, add10)
+
+
 def pipe_test():
-    piped = pipe(sub2, double, add10)
     assert_equal(piped(100), (100 - 2) * 2 + 10)
+
+
+def compose_multiple_args_test():
+    assert_equal(pipe(add, negate)(1, 2), -3)
+
+
+def compose_empty_args_test():
+    assert_equal(pipe(lambda: 42, negate)(), -42)
