@@ -3,4 +3,4 @@ from ramda.private.asserts import *
 
 
 def until_test():
-    assert_equal(until(lt(100), multiply(2))(1), 128)
+    assert_equal(until(gt(100), multiply(2))(1), 128)
